==> linuxcan_5_37_686.tar.gz: linuxcan/mhydra/mhydraHWIf_TRP.h <==
/*
**             Copyright 2019 by Kvaser AB, Molndal, Sweden
**                         http://www.kvaser.com
**
** This software is dual licensed under the following two licenses:
** BSD-new and GPLv2. You may use either one. See the included
** COPYING file for details.
**
** License: BSD-new
** ==============================================================================
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the <organization> nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
** IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**
**
** License: GPLv2
** ==============================================================================
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
**
**
** IMPORTANT NOTICE:
** ==============================================================================
** This source code is made available for free, as an open license, by Kvaser AB,
** for use with its applications. Kvaser AB does not accept any liability
** whatsoever for any third party patent or other immaterial property rights
** violations that may result from any usage of this source code, regardless of
** the combination of source code and various applications that it can be used
** in, or with.
**
** -----------------------------------------------------------------------------
*/

// Linux Mhydra driver routines for printf and trp 

#ifndef _MHYDRA_HW_IF_TRP_H_
#define _MHYDRA_HW_IF_TRP_H_

// defines for script/error/info printf's
#define DM_UNSUBSCRIBE           0x1
#define DM_SUBSCRIBE             0x2
#define DM_ENTITY_MASK_TYPE      0xff000000
#define DM_ENTITY_MASK_BROADCAST 0xf0000000
#define DM_TRAFFIC_BROADCAST     0x10000000
#define DM_DEBUG_BROADCAST       0x20000000
#define DM_ERROR_BROADCAST       0x30000000
#define DM_HE(n)                 (0x01000000 | n) // DEBUG/ERROR
#define DM_SCRIPT(n)             (0x02000000 | n) // TRAFFIC
#define DM_ENTITY_MASK_HAS_ID    0x0f000000
#define DM_ENTITY_MASK_ID        0x000000ff
#define DM_GROUP(n)              (0x00400000 | (n << 16))
#define DM_LEVEL(n)              (0x00001000 | (n <<  8))
#define DM_ALL                   0xff

int mhydra_device_messages_subscription(VCanOpenFileNode *fileNodePtr, KCAN_IOCTL_DEVICE_MESSAGES_SUBSCRIPTION_T *sc);

void printf_msg(VCanCardData *vCard, hydraHostCmd *cmd);

void fatal_msg (VCanCardData *vCard, hydraHostCmd *tmpCmd);

void trp_msg (VCanCardData *vCard, hydraHostCmd *tmpCmd);


#endif  /* _MHYDRA_HW_IF_TRP_H_ */

==> linuxcan_5_47_912.tar.gz: linuxcan/mhydra/mhydraHWIf_TRP.h <==
/*
**             Copyright 2023 by Kvaser AB, Molndal, Sweden
**                         http://www.kvaser.com
**
** This software is dual licensed under the following two licenses:
** BSD-new and GPLv2. You may use either one. See the included
** COPYING file for details.
**
** License: BSD-new
** ==============================================================================
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are met:
**     * Redistributions of source code must retain the above copyright
**       notice, this list of conditions and the following disclaimer.
**     * Redistributions in binary form must reproduce the above copyright
**       notice, this list of conditions and the following disclaimer in the
**       documentation and/or other materials provided with the distribution.
**     * Neither the name of the <organization> nor the
**       names of its contributors may be used to endorse or promote products
**       derived from this software without specific prior written permission.
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
** AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
** LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
** CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
** SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
** IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
** ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
** POSSIBILITY OF SUCH DAMAGE.
**
**
** License: GPLv2
** ==============================================================================
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
**
**
** IMPORTANT NOTICE:
** ==============================================================================
** This source code is made available for free, as an open license, by Kvaser AB,
** for use with its applications. Kvaser AB does not accept any liability
** whatsoever for any third party patent or other immaterial property rights
** violations that may result from any usage of this source code, regardless of
** the combination of source code and various applications that it can be used
** in, or with.
**
** -----------------------------------------------------------------------------
*/

// Linux Mhydra driver routines for printf and trp

#ifndef _MHYDRA_HW_IF_TRP_H_
#define _MHYDRA_HW_IF_TRP_H_

// defines for script/error/info printf's
#define DM_UNSUBSCRIBE           0x1
#define DM_SUBSCRIBE             0x2
#define DM_ENTITY_MASK_TYPE      0xff000000
#define DM_ENTITY_MASK_BROADCAST 0xf0000000
#define DM_TRAFFIC_BROADCAST     0x10000000
#define DM_DEBUG_BROADCAST       0x20000000
#define DM_ERROR_BROADCAST       0x30000000
#define DM_HE(n)                 (0x01000000 | n) // DEBUG/ERROR
#define DM_SCRIPT(n)             (0x02000000 | n) // TRAFFIC
#define DM_ENTITY_MASK_HAS_ID    0x0f000000
#define DM_ENTITY_MASK_ID        0x000000ff
#define DM_GROUP(n)              (0x00400000 | (n << 16))
#define DM_LEVEL(n)              (0x00001000 | (n << 8))
#define DM_ALL                   0xff

int mhydra_device_messages_subscription(VCanOpenFileNode *fileNodePtr,
                                        KCAN_IOCTL_DEVICE_MESSAGES_SUBSCRIPTION_T *sc);

void printf_msg(VCanCardData *vCard, hydraHostCmd *cmd);

void fatal_msg(VCanCardData *vCard, hydraHostCmd *tmpCmd);

void trp_msg(VCanCardData *vCard, hydraHostCmd *tmpCmd);

#endif /* _MHYDRA_HW_IF_TRP_H_ */
